@@ -68,8 +68,8 @@ class Mellisuga(object):
         self.actions[action] = route_func
 
     def _error_response(self, message, error_code, http_status_code):
-        body = {'Code': error_code, 'Message': message}
-        response = self.api.new_response(body=body, status_code=http_status_code)
+        data = {'Code': error_code, 'Message': message}
+        response = self.api.new_response(data=data, status_code=http_status_code)
         return response
 
     def __call__(self, event, context):
@@ -97,7 +97,7 @@ class Mellisuga(object):
                     error_code='MethodNotAllowedError',
                     message='Unsupported method: %s' % rest_method,
                     http_status_code=405)
-            route_func == self.paths[route][rest_method]
+            route_func = self.paths[route][rest_method]
         elif self.default_route:
             route_func = self.default_route
         else:
